@@ -4,6 +4,12 @@ function(pdb, string=NULL,
          eleno=NULL, elety=NULL,
          verbose=TRUE, rm.insert=FALSE) {
 
+  
+  ## Version 0.3 ... Thu May 12 17:38:25 PDT 2011
+  ##
+  ##  Removed old "pdb.summary()" section and replaced
+  ##   with call to new "print.pdb()" function.
+  ##
   ## Version 0.2 ... Tue Jun 23 18:15:28 PDT 2009
   ##
   ##  Builds selection string from components 
@@ -43,44 +49,6 @@ function(pdb, string=NULL,
   if (missing(pdb)) {
     stop("atom.select: must supply 'pdb' object, e.g. from 'read.pdb'")
   }
-  
-  
-  pdb.bounds <- function(nums) {
-    
-    # find the 'bounds' (i.e. the
-    # start, end and length) of a
-    # concetive range of residue
-    # or atom numbers.
-
-    nums   <- as.numeric(nums)
-    bounds <- nums[1]
-    diff.i <- 1; j <- 1
-    nums.start <- nums[1] 
-    store.inds <- NULL 
-    # also store ind of 1st atom of new res
-    for (i in 2:length(nums)) {
-      if (nums[i] != nums[j]) { # for resno
-        if ((nums[i] - diff.i)!= nums.start) {
-          bounds <- c(bounds,nums[i-1],nums[i])
-          nums.start <- nums[i]
-          diff.i <- 1
-        } else { diff.i <- diff.i + 1 }
-        store.inds <- c(store.inds,i)
-      }
-      j<-j+1
-    }
-
-    bounds<-c(bounds, nums[length(nums)])
-    bounds<-matrix( bounds, ncol=2, byrow=TRUE,
-                   dimnames=list( NULL, #c(1:(length(bounds)/2),
-                     c("start","end")) )
-
-    bounds<-cbind(bounds,length=(bounds[,2]-bounds[,1])+1)
-    
-    return(list(bounds=bounds,r.ind=store.inds))
-
-  }
-  
 
   
   sel.txt2nums <- function (num.sel.txt) {
@@ -112,32 +80,10 @@ function(pdb, string=NULL,
     return( gsub(" ","",type1) )
   }
 
-  ##- No selection string
+  ##- No selection string, just print PDB summary
   if(is.null(string)) {
     if(is.null(c(chain,resno,resid,eleno,elety))) {
-##      stop("atom.select: must supply a selection 'string'")
-      ##- Summary if called without a selection string
-      sum.segid <- unique(pdb$atom[,"segid"])
-      sum.chain <- unique(pdb$atom[,"chain"])
-      sum.rnum  <- pdb.bounds(pdb$atom[,"resno"])
-      sum.resno <- sum.rnum$bounds
-      sum.resid <- table(pdb$atom[sum.rnum$r.ind,"resid"])
-      sum.eleno <- pdb.bounds(pdb$atom[,"eleno"])$bounds
-      sum.elety <- table(pdb$atom[,"elety"])
-      
-      cat(" * Structure Summary *",sep="\n")
-      cat("---- segid ----",sep="\n");
-      print(sum.segid)
-      cat("---- chain ----",sep="\n");
-      print(sum.chain)
-      cat("---- resno ----",sep="\n")
-      print(sum.resno)
-      cat("---- resid ----",sep="\n");
-      print(sum.resid)
-      cat("---- eleno ----",sep="\n");
-      print(sum.eleno)
-      cat("---- elety ----",sep="\n");
-      print(sum.elety)
+      print.pdb(pdb)  ## -- Edit May 12 2011
       return()
     }
     ## Build selection string from components
@@ -165,7 +111,7 @@ function(pdb, string=NULL,
     if (string=="all") {
       string= "///////"
     }
-    ## - Addation Jan 17 2008
+    ## - Edit Jan 17 2008
     if (string=="h") {
       h.atom <- which( substr(pdb$atom[,"elety"], 1, 1) %in% "H" )
       match <- list(atom=h.atom, xyz=atom2xyz(h.atom))
@@ -184,7 +130,7 @@ function(pdb, string=NULL,
     }
     
     
-    ## - end addation
+    ## - end edit
     
     # main function  
     sel <- unlist(strsplit(string, split = "/"))
