@@ -43,10 +43,10 @@ function(seq, database="pdb") {
   while(length(html) == 1) {
     cat("."); Sys.sleep(5)
     
-    raw  <- read.csv(urlget,
+    raw  <- try(read.csv(urlget,
                      header = FALSE, sep = ",", quote="\"", dec=".",
-                     fill = TRUE, comment.char="")
-
+                     fill = TRUE, comment.char=""), silent=TRUE)
+    if(class(raw)=="try-error") { stop("No hits found: thus no output generated") }
     html <- grep("DOCTYPE", raw[1,])
   }
 
