@@ -17,7 +17,10 @@ function (nums, dup.inds=FALSE, pre.sort=TRUE) {
       bounds <- sort(nums)
       bounds <- c(bounds, (bounds[2]-bounds[1]+1))
       names(bounds) <- c("start", "end", "length")
-      return(bounds)
+      ## Edit here to return matrix (not vector) 
+      ## following dssp bug report from Yun Liu
+      ## Fri, Apr 29, 2011
+     return( t(as.matrix(bounds)) )
     }
 
     if(pre.sort) {
