@@ -1,5 +1,5 @@
 `dist.xyz` <-
-function(a, b=NULL){
+function(a, b=NULL, all.pairs=TRUE){
 
   ## if 'a' is a vector (or matrix) and 
   ## 'b' is a matrix
@@ -37,10 +37,20 @@ function(a, b=NULL){
     warning(paste("input does not have three columns: assuming you want",
                   dima, "dimensional distances")) 
   }
-  d <- matrix(0, nrow=nrow(a), ncol=nrow(b))
-  for(i in 1:nrow(a)){
-    d[i,] <- sqrt(colSums((a[i,] - t(b))^2))
+
+  if(!all.pairs) {
+    ## distance between coresponding rows
+    d <- rep( NA, max(nrow(a), nrow(b)) )
+    ind <- 1:min(nrow(a), nrow(b))
+    d[ind] <- sqrt( rowSums((a[ind,] - b[ind,])^2) )
+    ##    return( sqrt( rowSums((a - b)^2) ) )
+    return(d)
+  } else {
+    d <- matrix(0, nrow=nrow(a), ncol=nrow(b))
+    for(i in 1:nrow(a)){
+      d[i,] <- sqrt(colSums((a[i,] - t(b))^2))
+    }
+    return(d)
   }
-  return(d)
 }
 
