@@ -1,13 +1,20 @@
 "identity" <-
-function( alignment ) {
-
+function( alignment , normalize=TRUE) {
+  
   if(is.list(alignment)) alignment <- alignment$ali
-
   alignment[is.gap(alignment)] = NA
 
   ide <- function(x, y) {
-    return( round( sum(x==y, na.rm=TRUE)/
-                  sum(complete.cases(cbind(x,y))), 3) )
+#### Edit by Heiko Strathmann
+#### Wed Aug  4 10:48:16 PDT 2010
+#### Fix for bug with all gap sequences
+    r <- sum(x==y, na.rm=TRUE)
+    t <- sum(complete.cases(cbind(x,y)))
+    if (normalize && t != 0) {
+      r <- r/t
+    }
+##################################
+    return( round(r, 3) )
   }
 
   nseq <- nrow(alignment)
