@@ -4,8 +4,8 @@
                         step=0.125, # step size
                         file=NULL,  # output pdb file
                         ... ) {     # args for write.pdb
-                      
-  ## make a trjactory of atomic displacments along a given pc  
+
+  ## make a trjactory of atomic displacments along a given pc
   if(class(pca)!="pca") {
     stop("input should be a list object of class 'pca' (from 'pca.xyz')")
   }
@@ -13,8 +13,14 @@
   nstep <- c(seq(step, to=mag, by=step))
   zcoor  <- cbind(sqrt(pca$L[pc])) %*% nstep
 
-  plus  <- apply(zcoor, 2, pca.z2xyz, pca)
-  minus <- apply( (-(zcoor)), 2, pca.z2xyz, pca)
+  ##- Bug fix: Fri Jun 15 14:49:24 EDT 2012
+  ##  plus  <- apply(zcoor, 2, pca.z2xyz, pca)
+  ##  minus <- apply( (-(zcoor)), 2, pca.z2xyz, pca)
+
+  scor  <- function(x,u,m) { return(x*u+m) }
+  plus  <- sapply(c(zcoor), scor, u=pca$U[,pc], m=pca$mean)
+  minus <- sapply(c(-zcoor), scor, u=pca$U[,pc], m=pca$mean)
+
   coor  <- t(cbind(pca$mean,
                    plus, plus[,rev(1:ncol(plus))],
                    pca$mean,
@@ -23,4 +29,3 @@
   write.pdb(xyz=coor, file=file, ...)
   return(coor)
 }
-
