@@ -1,5 +1,5 @@
 "pdb.summary" <-
 function(pdb) {
-  atom.select(pdb)
+  print.pdb(pdb)
 }
 
