@@ -11,6 +11,20 @@ function (file, maxlines=50000, multi=FALSE,
   if(!is.logical(multi)) {
     stop("read.pdb: 'multi' must be logical TRUE/FALSE")
   }
+
+  ## Check if file exists localy or online
+  toread <- file.exists(file)
+  if(substr(file,1,4)=="http") { toread <- TRUE }
+
+  ## Check for 4 letter code and possible online file
+  if(!toread) {
+    if(nchar(file)==4) {
+      file <- get.pdb(file, URLonly=TRUE)
+      cat("  Note: Accessing online PDB file\n")
+    } else {
+      stop("No input PDB file found: check filename")
+    }
+  }
   
   # PDB FORMAT v2.0:    colpos,  datatype,    name,      description
   atom.format <- matrix(c(-6,     NA,          NA,       # (ATOM)
@@ -100,8 +114,21 @@ function (file, maxlines=50000, multi=FALSE,
   if (verbose) {
     if (!is.character0(raw.header)) { cat(" ", raw.header, "\n") }
   }
-  seqres <- unlist(strsplit( trim(substring(raw.seqres,19,80))," +"))
+  ## Edit from Baoqiang Cao <bqcao@ices.utexas.edu> Nov 29, 2009
+  ## Old version:
+  ##  seqres <- unlist(strsplit( trim(substring(raw.seqres,19,80))," +"))
+  ## New version
 
+  seqres <- unlist(strsplit( trim(substring(raw.seqres,19,80))," +"))
+  if(!is.null(seqres)) {
+    seqres.ch <- substring(raw.seqres, 12, 12)
+    seqres.ln <- substring(raw.seqres, 13, 17)
+    seqres.in <- ( !duplicated(seqres.ch) )
+    names(seqres) <- rep(seqres.ch[seqres.in], times=seqres.ln[seqres.in])
+  }
+  ## End Edit from Baoqiang:
+
+  
   helix  <- list(start = as.numeric(substring(raw.helix,22,25)),
                  end   = as.numeric(substring(raw.helix,34,37)),
                  chain = trim(substring(raw.helix,20,20)),
