@@ -40,12 +40,12 @@ function(aln, id=NULL,
 
   ### Update for muscle v3.8 with no "-stable" option
   ###  Thu Aug 26 18:29:38 PDT 2010
-  naln <- read.fasta(file)
+  naln <- read.fasta(file, rm.dup=FALSE)
   if(!seqgroup) {
-    ord <- match(naln$id, aln$id)
-    if( any( duplicated(ord) ) ) {
-      stop(" Duplicated sequence id's, so can't perserve input order\n\tPlease run with 'seqgroup=TRUE' option")
-    }
+    ord <- match(aln$id, naln$id)
+##    if( any( duplicated(ord) ) ) {
+##      stop(" Duplicated sequence id's, so can't perserve input order\n\tPlease run with 'seqgroup=TRUE' option")
+##    }
     naln$id <- naln$id[ord]
     naln$ali <- naln$ali[ord,]
   }
