@@ -16,7 +16,7 @@ function(pdb.files, path="split_chain/") {
   
   dir.create(path)
   for(i in 1:length(pdb.files)) {
-    pdb <- read.pdb(pdb.files[i], het2atom=TRUE)
+    pdb <- read.pdb(pdb.files[i], het2atom=TRUE, maxlines=-1)
     chains <- unique(pdb$atom[,"chain"])
     if(length(chains) > 0) {
       for(j in 1:length(chains)) {
