@@ -1,5 +1,9 @@
 "write.fasta" <-
-function (alignment=NULL, ids=NULL, seqs=alignment$ali, file, append = FALSE) {
+function(alignment=NULL,
+         ids=NULL,
+         seqs=alignment$ali,
+         file,
+         append = FALSE) {
   
   if (is.null(seqs))
     stop("write.fasta: please provide a 'seqs' or 'alignment' input object")
@@ -19,8 +23,10 @@ function (alignment=NULL, ids=NULL, seqs=alignment$ali, file, append = FALSE) {
     }
   } 
 
-  if (!append)
-    file.remove(file, showWarnings = FALSE)
+  if (!append) {
+    ##file.remove(file, showWarnings = FALSE)
+    suppressWarnings( file.remove(file) )
+  }
   nseqs <- length(ids)
   if (nseqs == 1) {
     cat(">", ids, "\n", seqs, "\n", file = file,
